@@ -1,7 +1,9 @@
-# $Id: BaseDriver.pm 14602 2008-03-05 18:31:19Z cjfields $
+# $Id: BaseDriver.pm 15561 2009-02-23 21:10:02Z cjfields $
 #
 # BioPerl module for Bio::DB::BioSQL::BaseDriver
 #
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+#
 # Cared for by Hilmar Lapp <hlapp at gmx.net>
 #
 # Copyright Hilmar Lapp
@@ -47,6 +49,17 @@ the Bioperl mailing list.  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
+=head2 Support 
+ 
+Please direct usage questions or support issues to the mailing list:
+  
+L<bioperl-l@bioperl.org>
+  
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
+
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
