@@ -1,7 +1,9 @@
-# $Id: SeqFeatureAdaptor.pm 567 2006-07-04 22:23:12Z mauricio $
+# $Id: SeqFeatureAdaptor.pm 15561 2009-02-23 21:10:02Z cjfields $
 #
 # BioPerl module for Bio::DB::BioSQL::SeqFeatureAdaptor
 #
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+#
 # Cared for by Ewan Birney <birney@ebi.ac.uk>
 #
 # Copyright Ewan Birney
@@ -50,6 +52,17 @@ Your participation is much appreciated.
 
   bioperl-l@bio.perl.org
 
+=head2 Support 
+ 
+Please direct usage questions or support issues to the mailing list:
+  
+L<bioperl-l@bioperl.org>
+  
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
+
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
