@@ -1,7 +1,9 @@
-# $Id: TermAdaptor.pm 15330 2009-01-11 22:39:22Z cjfields $
+# $Id: TermAdaptor.pm 15561 2009-02-23 21:10:02Z cjfields $
 #
 # BioPerl module for Bio::DB::BioSQL::TermAdaptor
 #
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+#
 # Cared for by Hilmar Lapp <hlapp at gmx.net>
 #
 # (c) Ewan Birney <birney@ebi.ac.uk>, 2002.
@@ -43,6 +45,17 @@ Your participation is much appreciated.
 
   bioperl-l@bioperl.org
 
+=head2 Support 
+ 
+Please direct usage questions or support issues to the mailing list:
+  
+L<bioperl-l@bioperl.org>
+  
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
+
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
